# Webform QR Code Element

This module supplies a Webform element that generates a QR code. It is
intended for emails sent to event participants and can be used for
faster check-in. The event organizer will use an app to scan the QR
code, which looks up the participant. Such an app might just show a
green checkmark if the participant is found, or show additional
information.

The QR code is only visible after the form is submitted, not while it is
being filled out.

This module doesn't have any participant tracking app yet. You need to
use your own. As the data source, you can export webform submissions
using **Results** » **Download**.\
Please [open an
issue](https://www.drupal.org/project/issues/webform_qr_code_element?categories=All)
if you have a publicly available solution.

## Installation

Install the module as you [would normally
install](https://www.drupal.org/node/1897420) a contributed Drupal
module.

## QR code content

The QR code represents a custom string. In this case, the content is
defined by the form author. In the wild, QR codes are often URLs, but
for the purpose of this module the QR code content doesn't have to be a
URL. The content is based on tokens, so that each submission gets a
different value. It should not be guessable. Examples are:

-   `[webform_submission:sid][webform_submission:created]`
-   `[webform_submission:token]`
-   `[webform_submission:token-view-url]`

Note that there are two distinct concepts called token:

-   The \[\] replacement syntax from the [Token
    module](https://drupal.org/project/token) and
-   the secure pseudo-random string used to look up a webform
    submission, for example
    AqMUTxvL00FOUIIKj-R6vK0mzEflYTVBzWCLVT_gNZ82.

## Add a QR code to the email of a webform

1.  Go to your webform\'s "Build" tab.

2.  Click on "Add element". Search for "QR Code" (it's in the **Computed
    Elements** section).

3.  Fill all mandatory fields.
    -   **Title** (and key) are just for you internally. They are not
        shown to the participants.
    -   **Text to store in the QR code** needs to be a value that is
        unique for each participant (and event). See examples above in
        the **QR code content** heading. Available tokens can be
        explored at the bottom of the form or on the page /token/tree of
        your Drupal installation.

4.  You probably want to hide the QR code to end users before the form
    is submitted. Make sure you picked the correct "Display on",
    probably **viewed submission only**.

5.  Go to **Settings » Emails / Handlers** and make sure that the QR
    code is part of the email. Here are example tokens you can add to
    Message » Body:

    -   `[webform_submission:values:html]`
    -   `[webform_submission:qr_code]`

    You should explain why there is a QR code in their email, for
    example like this:

    > Dear \[webform_submission:values:first_name\],\
    > \
    > Thank you for registering for our event! We\'re excited to welcome
    > you and ensure you have a fantastic experience.\
    > \
    > Please note that the following QR code is for the organizers to
    > scan at the event admission. When you arrive, simply present the
    > QR code at the check-in area, and our team will take care of the
    > rest:\
    > \[webform_submission:qr_code\]\
    > \
    > If you have any questions or need further assistance, feel free to
    > reach out to us at *XYZ*.\
    > \
    > We look forward to seeing you at the event!\
    > \
    > Best regards,\
    > *XYZ*

6.  Fill your form like a participant would to test how the email looks
    like.

## Maintainer

[Christian "Gogowitsch" Bläul](https://drupal.org/u/gogowitsch)
