<?php

namespace Drupal\webform_qr_code_element\Element;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Markup;
use Drupal\webform\Element\WebformComputedToken;
use Drupal\webform\WebformSubmissionInterface;
use Drupal\webform_qr_code_element\Controller\QrCodeController;
use Endroid\QrCode\Builder\Builder;
use Endroid\QrCode\Encoding\Encoding;
use Endroid\QrCode\ErrorCorrectionLevel;
use Endroid\QrCode\RoundBlockSizeMode;
use Endroid\QrCode\Writer\PngWriter;
use Symfony\Component\Routing\Exception\InvalidParameterException;

/**
 * @FormElement("qr_code")
 */
class QrCodeElement extends WebformComputedToken {

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    $class = get_class($this);

    return [
        '#process' => [
          [$class, 'processWebformComputed'],
        ],
      ] + parent::getInfo();
  }

  public static function processWebformComputed(&$element, FormStateInterface $form_state, &$complete_form) {
    parent::processWebformComputed($element, $form_state, $complete_form);
    $text = $element['value']['#markup'];
    $element['value'] = self::renderImage($text, $element);

    return $element;
  }

  public static function computeValue(array $element, WebformSubmissionInterface $webform_submission) {
    if (strpos($element['#template'], 'token-view-url') > 0) {
      if (!$webform_submission->id()) {
        return "not enough context";
      }
    }
    try {
      return parent::computeValue($element, $webform_submission);
    }
    catch (InvalidParameterException $e) {
      return "Missing context: " . $e->getMessage();
    }
  }

  public static function renderImage(string $text, array $element): array {
    $show_label_below_code = $element['#show_label_below_code'] ?? FALSE;
    $builder = new Builder(
      writer: new PngWriter(),
      writerOptions: [],
      validateResult: FALSE,
      data: $text,
      encoding: new Encoding('UTF-8'),
      errorCorrectionLevel: ErrorCorrectionLevel::High,
      size: 300,
      margin: 10,
      roundBlockSizeMode: RoundBlockSizeMode::Margin,
      labelText: $show_label_below_code ? $text : ''
    );

    $alt = htmlentities($element['#title'] ?? '');
    $dataUri = $builder->build()->getDataUri();
    return ['#markup' => Markup::create(sprintf('<img alt="%s" src="data:%s">', $alt, $dataUri))];
  }

}
