<?php

namespace Drupal\webform_qr_code_element\Plugin\WebformElement;

use Drupal\Core\Form\FormStateInterface;
use Drupal\webform\Element\WebformComputedInterface;
use Drupal\webform\Plugin\WebformElement\WebformComputedToken;
use Drupal\webform\Plugin\WebformElementDisplayOnInterface;
use Drupal\webform\WebformSubmissionInterface;
use Drupal\webform_qr_code_element\Element\QrCodeElement;

/**
 * @WebformElement(
 *   id = "qr_code",
 *   label = @Translation("QR Code"),
 *   description = @Translation("A QR code indented for emails sent to event participants and can be used for faster check-in."),
 *   category = @Translation("Computed Elements"),
 * )
 */
class QrCode extends WebformComputedToken {

  /**
   * {@inheritdoc}
   */
  protected function defineDefaultProperties() {
    return [
        'display_on' => WebformElementDisplayOnInterface::DISPLAY_ON_VIEW,
        'mode' => WebformComputedInterface::MODE_TEXT,
        'show_label_below_code' => FALSE,
        'store' => TRUE,
        'template_format' => '',
        'title' => t('QR code for admission'),
      ] + parent::defineDefaultProperties();
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);
    $form['computed']['template'] = [
      '#type' => 'textfield',
      '#required' => TRUE,
      '#help' => '',
      '#title' => t('Text to store in the QR code'),
      '#description_display' => 'after',
      '#description' => t('This needs to be a string that is unique and not guessable.') . '<br>' .
        t('Examples') . ':<br>' .
        '• [webform_submission:sid]-[webform_submission:created]<br>' .
        '• [webform_submission:token]',
    ];

    $form['image_settings'] = [
      '#type' => 'fieldset',
      '#title' => t('Image settings'),
      'show_label_below_code' => [
        '#type' => 'checkbox',
        '#return_value' => TRUE,
        '#title' => t('Show label below QR code'),
      ],
    ];

    // Inherited from base class, but not needed:
    unset($form['computed']['mode'], $form['computed']['whitespace'], $form['computed']['hide_empty'], $form['form']['prepopulate']);
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function formatHtml(array $element, WebformSubmissionInterface $webform_submission, array $options = []) {
    $value = $this->getValue($element, $webform_submission, $options);
    return QrCodeElement::renderImage($value, $element)['#markup'];
  }

}
